#include "xgpiops.h"

XGpioPs_Config XGpioPs_ConfigTable[] __attribute__ ((section (".drvcfg_sec"))) = {

	{
		"xlnx,versal-gpio-1.0", /* compatible */
		0xf1a50000, /* reg */
		0x4014, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	{
		"xlnx,pmc-gpio-1.0", /* compatible */
		0xf1020000, /* reg */
		0x40ca, /* interrupts */
		0xe2000000 /* interrupt-parent */
	},
	 {
		 NULL
	}
};